@@ -9,7 +9,7 @@
 #'
 #' @export
 
-tcspoints<- function(tcsdata, size=0.02, col='black'){
+tcspoints<- function(tcsdata, size=0.02, col='black', alpha=1){
 
 # if(class(tcsdata)=='tcs'){
   # dat <- tcsdata$tcs  
@@ -18,5 +18,5 @@ tcspoints<- function(tcsdata, size=0.02, col='black'){
     # }
 
 
-spheres3d(tcsdata[,c('x','y','z')], radius=size, color=col, lit=F)
+spheres3d(tcsdata[,c('x','y','z')], radius=size, color=col, lit=F, alpha=alpha)
 }
